package com.inspect.alarmdifferent.service.impl;

import com.inspect.alarmdifferent.domain.AlarmDifferent;
import com.inspect.alarmdifferent.mapper.AlarmDifferentMapper;
import com.inspect.alarmdifferent.service.IAlarmDifferentService;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AlarmDifferentServiceImpl implements IAlarmDifferentService {
    private final AlarmDifferentMapper alarmDifferentMapper;

    public AlarmDifferentServiceImpl(AlarmDifferentMapper alarmDifferentMapper) {
        this.alarmDifferentMapper = alarmDifferentMapper;
    }

    public AlarmDifferent selectAlarmDifferentByLineId(Long lineId) {
        return this.alarmDifferentMapper.selectAlarmDifferentByLineId(lineId);
    }

    public List<AlarmDifferent> selectAlarmDifferentList(AlarmDifferent alarmDifferent) {
        return this.alarmDifferentMapper.selectAlarmDifferentList(alarmDifferent);
    }

    public int insertAlarmDifferent(AlarmDifferent alarmDifferent) {
        return this.alarmDifferentMapper.insertAlarmDifferent(alarmDifferent);
    }

    public int updateAlarmDifferent(AlarmDifferent alarmDifferent) {
        return this.alarmDifferentMapper.updateAlarmDifferent(alarmDifferent);
    }

    public int deleteAlarmDifferentByLineIds(Long[] lineIds) {
        return this.alarmDifferentMapper.deleteAlarmDifferentByLineIds(lineIds);
    }

    public int deleteAlarmDifferentByLineId(Long lineId) {
        return this.alarmDifferentMapper.deleteAlarmDifferentByLineId(lineId);
    }
}
